<?php
/**
 * Glow Theme Customizer.
 *
 * @package Glow
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function glow_customize_register( $wp_customize ) {
//	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	// Primary Color
	$wp_customize->add_setting( 'glow_primary_color', array(
		'default' 			     => '#fa7921',
		'capability' 			 => 'edit_theme_options',
		'sanitize_callback'		 => 'glow_color_sanitize',
		'sanitize_js_callback'   => 'glow_color_escaping_sanitize'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'glow_primary_color', array(
		'priority' 				 => 10,
		'label' 				 => __( 'Primary Color', 'glow' ),
		'section' 				 => 'colors',
		'settings' 				 => 'glow_primary_color'
	) ) );

	// Home Page Featured posts
	$wp_customize->add_section( 'home_featured_posts', array(
			'title' 			=> __( 'Home Page Slider', 'glow' )
	));

	$wp_customize->add_setting( 'home_featured_posts', array(
			'default' 			=> '',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'glow_checkbox_sanitize'
	));

	$wp_customize->add_control( 'home_featured_posts', array(
			'type' 				=> 'checkbox',
			'label' 			=> __( 'Check to enable featured posts', 'glow' ),
			'settings' 			=> 'home_featured_posts',
			'section' 			=> 'home_featured_posts'
	));

	$cats = array();
	foreach ( get_categories() as $categories => $category ){
		$cats[$category->term_id] = $category->name;
	}

	$wp_customize->add_setting( 'home_featured_posts_select', array(
		'default' => 1,
		'sanitize_callback' => 'absint'
	) );

	$wp_customize->add_control( 'home_featured_posts_select', array(
		'type'      => 'select',
		'label' 	=> __( 'Select Category', 'glow' ),
		'choices'   => $cats,
		'settings'  => 'home_featured_posts_select',
		'section'   => 'home_featured_posts'
	) );

    $wp_customize->add_setting( 'dt_slide_number', array(
        'default' 			=> '3',
        'capability' 		=> 'edit_theme_options',
        'sanitize_callback' => 'glow_sanitize_integer'
    ));

    $wp_customize->add_control( 'dt_slide_number', array(
        'type'			 	=> 'number',
        'label' 			=> __( 'No. of Slide', 'glow' ),
        'section'			=> 'home_featured_posts',
        'settings' 			=> 'dt_slide_number'
    ));

	// Checkbox Sanitize
	function glow_checkbox_sanitize( $input ) {
		if ( $input == 1 ) {
			return 1;
		} else {
			return '';
		}
	}

	// Color Sanitize
	function glow_color_sanitize( $color ) {
		if ( $unhashed = sanitize_hex_color_no_hash( $color ))
			return '#' . $unhashed;
		return $color;
	}

	// Color Escape Sanitize
	function glow_color_escaping_sanitize( $input ) {
		$input = esc_attr( $input );
		return $input;
	}

	// Number Integer
	function glow_sanitize_integer( $input ) {
		return absint( $input );
	}
}
add_action( 'customize_register', 'glow_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function glow_customize_preview_js() {
	wp_enqueue_script( 'glow_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'glow_customize_preview_js' );

/**
 * Enqueue Inline styles generated by customizer
 */
function glow_customizer_styles() {

	$get_header_textcolor = get_header_textcolor();

	if ( $get_header_textcolor != '000000' && $get_header_textcolor != '' ) {
		$glow_header_textcolor = "
	h1.site-title a,
	.site-description {
		color: #{$get_header_textcolor} !important;
	}
	";
	} else {
		$glow_header_textcolor = '';
	}

	$primary_color = esc_attr( get_theme_mod( 'glow_primary_color' ) );

	if ( $primary_color != '#fa7921' && $primary_color != '' ) {
		$glow_primary_color = "
	a:hover,
	.dt-main-menu li:hover > a,
	.dt-services .dt-entry-header h2 span,
	.dt-testimonial-wrap .dt-entry-header h2 span,
	.dt-news-layout-wrap .dt-entry-header h2  spa,
	.dt-services-header:hover h3 a,
	.dt-call-to-action-btn a,
	.dt-footer-bar a:hover,
	.dt-pagination-nav a:hover,
	.dt-pagination-nav .current:hover,
	.dt-pagination-nav .current {
		color: {$primary_color};
	}

	.dt-main-menu .menu > li > a:hover,
	.current-menu-item > a,
	.current_page_item > a {
		color: {$primary_color} !important;
		border-color: {$primary_color} !important;
	}

	.dt-call-to-action-btn a,
	.dt-opening-hours,
	.dt-pagination-nav a:hover,
	.dt-pagination-nav .current:hover,
	.dt-pagination-nav .current {
		border-color: {$primary_color};
	}

	.sticky article {
		border-color: {$primary_color} !important;
	}

	.dt-featured-post-slider .swiper-button-next:hover,
	.dt-featured-post-slider .swiper-button-prev:hover,
	.dt-services-holder span,
	.dt-call-to-action-btn a:hover,
	.tagcloud a:hover,
	.dt-footer h2 span,
	.dt-about-header h2 span,
	.dt-right-sidebar h2 span,
	.dt-right-sidebar h2 span,
	.dt-right-sidebar .dt-recent-posts h2 span,
	.dt-archive-post .entry-footer a:hover,
	#back-to-top:hover {
		background: {$primary_color};
	}
	";
	} else {
		$glow_primary_color = '';
	}

	$custom_css = $glow_header_textcolor . $glow_primary_color ;

	wp_add_inline_style( 'glow-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'glow_customizer_styles' );
